(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     34133,       1231]*)
(*NotebookOutlinePosition[     34798,       1254]*)
(*  CellTagsIndexPosition[     34754,       1250]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default \
appearance of all cells in a given style.
Make modifications to any definition using commands in the Format \
menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  ScriptMinSize->12,
  FontSize->18],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  ScriptMinSize->8],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Notebook"],
  ShowCellBracket->True,
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->GrayLevel[0.500008]},
  StyleMenuListing->None,
  Background->RGBColor[0.900008, 0.863996, 0.809995]],

Cell[StyleData["Notebook", "Lecture"],
  ShowCellBracket->True,
  CellBracketOptions->{"Color"->GrayLevel[1]},
  StyleMenuListing->None,
  Background->GrayLevel[1]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellFrame->{{0, 0}, {5, 0}},
  ShowCellBracket->False,
  CellMargins->{{54, 45}, {20, 20}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameColor->GrayLevel[0],
  TextAlignment->Left,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Times",
  FontSize->36,
  FontWeight->"Plain",
  FontColor->RGBColor[0.0941176, 0.294118, 0.505882],
  Background->RGBColor[0.900008, 0.863996, 0.809995]],

Cell[StyleData["Title", "Lecture"],
  CellFrame->{{0, 0}, {5, 0}},
  CellMargins->{{48, Inherited}, {20, 20}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0, 0.4, 0.6],
  TextAlignment->Left,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Bookman",
  FontSize->36,
  Background->None],

Cell[StyleData["Title", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{100, 100}, {50, 50}},
  LineSpacing->{1, 0},
  FontSize->50,
  FontColor->RGBColor[0.0941176, 0.294118, 0.505882]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{48, 40}, {10, Inherited}},
  CellFrameColor->GrayLevel[0.8],
  TextAlignment->Center,
  FontFamily->"B Frutiger Bold",
  FontSize->24],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellFrame->{{10, 0}, {5, 5}},
  ShowCellBracket->True,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{54, 45}, {10, 30}},
  CellElementSpacings->{"CellMinHeight"->12},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0.900008, 0.863996, 0.809995],
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0.0941176, 0.294118, 0.505882],
  Background->RGBColor[0.900008, 0.863996, 0.809995],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->True}],

Cell[StyleData["Subtitle", "Lecture"],
  CellMargins->{{54, Inherited}, {10, 30}},
  CellElementSpacings->{"CellMinHeight"->12},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CellFrameMargins->2,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->RGBColor[0, 0.4, 0.6],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subtitle", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{24, Inherited}, {6, Inherited}},
  LineSpacing->{1, 0},
  FontSize->30],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{42, Inherited}, {6, Inherited}},
  FontSize->18,
  Background->GrayLevel[0.500008]],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  ShowCellBracket->False,
  CellMargins->{{54, Inherited}, {40, Inherited}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  TextAlignment->Left,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[0.19765, 0.19765, 0.241566]],

Cell[StyleData["Subsubtitle", "Lecture"],
  CellMargins->{{48, Inherited}, {40, Inherited}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  TextAlignment->Left,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{100, 100}, {50, 0}},
  LineSpacing->{1, 0},
  FontSize->12,
  FontSlant->"Plain"],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{48, 40}, {20, Inherited}},
  TextAlignment->Center,
  FontFamily->"I Frutiger Italic",
  FontSize->10],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->False,
  ShowCellBracket->True,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{72, 60}, {20, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0.0941176, 0.294118, 0.505882],
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.0941176, 0.294118, 0.505882]],

Cell[StyleData["Section", "Lecture"],
  CellFrame->{{0, 0}, {2, 0}},
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{42, Inherited}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0, 0.4, 0.6],
  LineSpacing->{1, 1},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Bookman",
  FontSize->20,
  FontWeight->"Plain"],

Cell[StyleData["Section", "Presentation"],
  CellFrame->{{0, 4}, {4, 0}},
  ShowCellBracket->False,
  CellMargins->{{100, 100}, {20, 20}},
  CellBracketOptions->{
  "Color"->RGBColor[0.241566, 0.219608, 0.19765]},
  CellFrameColor->RGBColor[0.80235, 0.780392, 0.758434],
  LineSpacing->{1, 0},
  FontSize->28,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.0941176, 0.294118, 0.505882]],

Cell[StyleData["Section", "Printout"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{42, Inherited}, {Inherited, 20}},
  FontFamily->"B Frutiger Bold",
  FontSize->16],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{42, Inherited}, {2, 2}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellFrame->{{0, 0}, {1, 0}},
  ShowCellBracket->True,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{94, 60}, {Inherited, 20}},
  CellElementSpacings->{"ClosedCellHeight"->30},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0.0941176, 0.294118, 0.505882],
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Times",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.0941176, 0.294118, 0.505882]],

Cell[StyleData["Subsection", "Lecture"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{59, Inherited}, {Inherited, 18}},
  CellElementSpacings->{"ClosedCellHeight"->30},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Bookman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0.4, 0.6]],

Cell[StyleData["Subsection", "Presentation"],
  CellFrame->{{20, 0}, {0, 0}},
  ShowCellBracket->False,
  CellMargins->{{117, 100}, {10, 20}},
  CellFrameColor->RGBColor[0.0941176, 0.294118, 0.505882],
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Subsection", "Printout"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{48, Inherited}, {Inherited, 15}},
  FontFamily->"B Frutiger Bold",
  FontSize->14,
  FontColor->GrayLevel[0]],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->12]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{108, Inherited}, {12, 30}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Lecture"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{78, Inherited}, {Inherited, 12}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Presentation"],
  CellFrame->{{0, 0}, {1, 0}},
  ShowCellBracket->False,
  CellMargins->{{144, 100}, {10, 20}},
  LineSpacing->{1, 0},
  FontSize->20],

Cell[StyleData["Subsubsection", "Printout"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{72, Inherited}, {Inherited, 12}},
  FontFamily->"BI Frutiger BoldItalic",
  FontSize->12],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  ShowCellBracket->False,
  CellMargins->{{94, 60}, {Inherited, Inherited}},
  TextJustification->0.75,
  FontFamily->"Times",
  FontSize->14],

Cell[StyleData["Text", "Lecture"],
  CellMargins->{{78, 60}, {Inherited, Inherited}},
  TextJustification->0.75,
  LineSpacing->{1.2, 1},
  FontFamily->"Bookman",
  FontSize->15],

Cell[StyleData["Text", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{144, 100}, {10, 10}},
  TextJustification->0.75,
  FontFamily->"Times New Roman",
  FontSize->20],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{76, 20}, {Inherited, Inherited}},
  TextJustification->1,
  FontFamily->"Sabon",
  FontSize->12],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{76, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{78, 60}, {Inherited, Inherited}},
  FontFamily->"Bookman",
  FontSize->10],

Cell[StyleData["SmallText", "Lecture"],
  CellMargins->{{78, 60}, {Inherited, Inherited}},
  TextJustification->0.75,
  LineSpacing->{1.2, 1},
  FontFamily->"Bookman",
  FontSize->12],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{78, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->14],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{78, Inherited}, {Inherited, Inherited}},
  FontSize->9],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{78, Inherited}, {2, 2}},
  FontSize->9]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Lists", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ListSquare"],
  CellFrame->{{5, 0}, {0, 0}},
  CellDingbat->"\[EmptySquare]",
  ShowCellBracket->False,
  CellMargins->{{117, 60}, {Inherited, Inherited}},
  CellFrameMargins->{{8, 4}, {8, 8}},
  CellFrameColor->RGBColor[0.900008, 0.863996, 0.809995],
  TextJustification->0.75,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[StyleData["ListSquare", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{180, 60}, {10, 10}},
  CellFrameMargins->{{8, 4}, {8, 8}},
  TextAlignment->Left,
  TextJustification->0.75,
  ParagraphIndent->10,
  FontSize->20],

Cell[StyleData["ListSquare", "Printout"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  TextJustification->1,
  FontFamily->"Sabon",
  FontSize->12]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["ListNumbered"],
  CellFrame->{{5, 0}, {0, 0}},
  ShowCellBracket->False,
  CellMargins->{{117, 60}, {Inherited, Inherited}},
  CellFrameMargins->{{8, 4}, {8, 8}},
  CellFrameColor->RGBColor[0.900008, 0.863996, 0.809995],
  TextJustification->0.75,
  ParagraphIndent->-16,
  TabSpacings->1.5,
  CounterIncrements->"ListNumbered",
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[StyleData["ListNumbered", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{162, 60}, {10, 10}},
  TextJustification->0.75,
  FontFamily->"Times New Roman",
  FontSize->20],

Cell[StyleData["ListNumbered", "Printout"],
  CellMargins->{{80, Inherited}, {Inherited, Inherited}},
  TextJustification->1,
  FontFamily->"Sabon",
  FontSize->12]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and \
output to the kernel.  Be careful when modifying, renaming, or \
removing these styles, because the front end associates special \
meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->{{5, 0}, {0, 0}},
  ShowCellBracket->True,
  CellMargins->{{117, 60}, {0, 10}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{4, 4}, {8, 8}},
  CellFrameColor->RGBColor[0.6, 0, 0],
  CellFrameLabelMargins->8,
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->RGBColor[0.984375, 0.841947, 0.450217]],

Cell[StyleData["Input", "Lecture"],
  CellFrame->{{5, 1}, {0.25, 0.25}},
  CellMargins->{{87, 23}, {20, 20}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{4, 4}, {8, 8}},
  CellFrameColor->RGBColor[0.6, 0, 0],
  CellFrameLabelMargins->8,
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->GrayLevel[0.900008]],

Cell[StyleData["Input", "Presentation"],
  CellFrame->{{5, 1}, {1, 1}},
  CellMargins->{{162, 100}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->18,
  FontWeight->"Plain"],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{90, 20}, {5, 10}},
  FontSize->10],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["InputDemo"],
  Editable->False,
  CellFrame->{{5, 0}, {0, 0}},
  ShowCellBracket->True,
  CellMargins->{{117, 60}, {0, 10}},
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{4, 4}, {8, 8}},
  CellFrameColor->RGBColor[0.6, 0, 0],
  CellFrameLabelMargins->8,
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.8, 0.4]],

Cell[StyleData["InputDemo", "Lecture"],
  CellFrame->{{5, 1}, {0.25, 0.25}},
  CellMargins->{{87, 23}, {20, 20}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{4, 4}, {8, 8}},
  CellFrameColor->RGBColor[0.6, 0, 0],
  CellFrameLabelMargins->8,
  DefaultFormatType->DefaultInputFormatType,
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold",
  Background->GrayLevel[0.900008]],

Cell[StyleData["InputDemo", "Presentation"],
  CellFrame->{{5, 1}, {1, 1}},
  CellMargins->{{162, 100}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->18,
  FontWeight->"Plain"],

Cell[StyleData["InputDemo", "Printout"],
  CellMargins->{{90, 20}, {5, 10}},
  FontSize->10],

Cell[StyleData["InputDemo", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellFrame->{{5, 0}, {0, 0.25}},
  ShowCellBracket->True,
  CellMargins->{{117, 60}, {10, -1}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{4, 4}, {8, 8}},
  CellFrameColor->RGBColor[0, 0.4, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Output", "Lecture"],
  CellFrame->{{5, 0}, {0.25, 0}},
  CellMargins->{{87, 23}, {10, -1}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{4, 4}, {8, 8}},
  CellFrameColor->RGBColor[0.6, 0, 0],
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm],

Cell[StyleData["Output", "Presentation"],
  CellFrame->{{5, 0}, {0, 0}},
  CellMargins->{{162, Inherited}, {20, Inherited}},
  CellFrameColor->RGBColor[1, 0, 0],
  LineSpacing->{1, 0},
  FontSize->16,
  FontColor->GrayLevel[0]],

Cell[StyleData["Output", "Printout"],
  CellFrame->{{5, 0}, {0, 0}},
  CellMargins->{{90, Inherited}, {15, Inherited}},
  FontSize->10],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{117, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{117, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Info"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Info", "Presentation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Info", "Printout"],
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Info", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellFrame->False,
  ShowCellBracket->True,
  CellMargins->{{117, 60}, {50, 20}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  CellFrame->2,
  CellMargins->{{180, 120}, {10, 30}},
  CellFrameColor->RGBColor[0.241566, 0.219608, 0.19765],
  LineSpacing->{1, 0},
  Background->GrayLevel[1]],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{81, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Graphics", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->14],

Cell[StyleData["CellLabel", "Printout"],
  FontSize->8,
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->8]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, \
figures, etc.  They automatically give the cell a FrameLabel \
containing a reference to a particular counter, and also increment \
that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  ShowCellBracket->False,
  CellMargins->{{72, 80}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  TextAlignment->-0.5,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[StyleData["NumberedEquation", "Lecture"],
  CellMargins->{{72, 80}, {10, 10}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  TextAlignment->-0.5,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontFamily->"Bookman",
  FontSize->18],

Cell[StyleData["NumberedEquation", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{100, 100}, {20, 20}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  TextAlignment->-0.5,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontFamily->"Times New Roman",
  FontSize->20],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{72, 20}, {Inherited, Inherited}},
  FontFamily->"Sabon"],

Cell[StyleData["NumberedEquation", "Condensed"],
  CellMargins->{{72, 72}, {Inherited, Inherited}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  ShowCellBracket->False,
  CellMargins->{{117, 60}, {20, 10}},
  CellFrameLabels->{{Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"], ". "}]], None}, {
      None, None}},
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False,
  FontFamily->"Helvetica",
  FontSize->12,
  FontColor->RGBColor[0.0941176, 0.294118, 0.505882],
  CounterBoxOptions->{CounterStyle->"Section",
  CounterFunction:>Identity,
  CounterEvaluator->Automatic}],

Cell[StyleData["NumberedFigure", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{144, 100}, {50, 20}},
  LineSpacing->{1, 0},
  FontSize->18],

Cell[StyleData["NumberedFigure", "Printout"],
  CellMargins->{{75, Inherited}, {Inherited, Inherited}},
  FontFamily->"I Frutiger Italic",
  FontSize->10],

Cell[StyleData["NumberedFigure", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}]], None}},
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedTable", "Presentation"],
  CellMargins->{{24, Inherited}, {20, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedTable", "Printout"],
  CellMargins->{{14, Inherited}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["NumberedTable", "Condensed"],
  CellMargins->{{4, Inherited}, {2, 2}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["LeftHeader"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["Footer"],
  TextAlignment->Center,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["LeftFooter"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same \
Notebook, or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.6, 0, 0],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Lecture"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.6, 0, 0],
  FontVariations->{"Underline"->False},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontSize->20,
  FontColor->RGBColor[0.6, 0, 0],
  FontVariations->{"Underline"->False},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}]
}, Open  ]],

Cell["\<\
The \"RefGuide\" style is for linking automatically to the \
on-line Reference Guide help system.\
\>", "Text"],

Cell[StyleData["RefGuide"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ #]}]&),
  Active->True}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None,
  DrawHighlighted->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the \
styles of most cells.  If a cell's FormatType matches the name of one \
of the styles defined below, then that style is applied between the \
cell's style and its own options.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{1, -5},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in \
an inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  CellMargins->{{0, 0}, {0, 0}},
  TextAlignment->Left,
  ScriptLevel->1,
  ImageMargins->{{0, 0}, {0, 0}},
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 746}},
WindowToolbars->"RulerBar",
WindowSize->{610, 628},
WindowMargins->{{Automatic, 72}, {44, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 65, "Subtitle"],
Cell[1816, 55, 192, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[2033, 64, 42, 0, 56, "Section"],
Cell[2078, 66, 51, 1, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2132, 69, 73, 2, 70, 36, 0, "StyleData", "All", "Presentation"],
Cell[2208, 73, 164, 4, 70, 33, 0, "StyleData", "All", "Condensed"],
Cell[2375, 79, 104, 2, 70, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2516, 86, 35, 0, 36, "Section"],
Cell[2554, 88, 101, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[2680, 95, 244, 5, 54, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None],
Cell[2927, 102, 164, 4, 38, 38, 0, "StyleData", "Notebook", "Lecture",
  StyleMenuListing->None]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3140, 112, 38, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[3203, 116, 490, 14, 113, 24, 0, "StyleData", "Title", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[3696, 132, 382, 11, 107, 35, 0, "StyleData", "Title", "Lecture",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4081, 145, 198, 5, 187, 40, 0, "StyleData", "Title", "Presentation"],
Cell[4282, 152, 188, 5, 93, 36, 0, "StyleData", "Title", "Printout"],
Cell[4473, 159, 94, 2, 65, 37, 0, "StyleData", "Title", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[4604, 166, 731, 21, 64, 27, 0, "StyleData", "Subtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5338, 189, 555, 17, 91, 38, 0, "StyleData", "Subtitle", "Lecture",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5896, 208, 158, 4, 95, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[6057, 214, 140, 3, 86, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[6200, 219, 97, 2, 54, 40, 0, "StyleData", "Subtitle", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6334, 226, 372, 10, 76, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[6709, 238, 329, 9, 76, 41, 0, "StyleData", "Subsubtitle", "Lecture",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[7041, 249, 171, 5, 78, 46, 0, "StyleData", "Subsubtitle", \
"Presentation"],
Cell[7215, 256, 162, 4, 51, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[7380, 262, 100, 2, 34, 43, 0, "StyleData", "Subsubtitle", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[7517, 269, 520, 14, 76, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[8040, 285, 440, 12, 86, 37, 0, "StyleData", "Section", "Lecture",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[8483, 299, 391, 10, 107, 42, 0, "StyleData", "Section", "Presentation"],
Cell[8877, 311, 170, 4, 90, 38, 0, "StyleData", "Section", "Printout"],
Cell[9050, 317, 97, 2, 51, 39, 0, "StyleData", "Section", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9184, 324, 536, 14, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[9723, 340, 424, 11, 66, 40, 0, "StyleData", "Subsection", "Lecture",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[10150, 353, 240, 6, 74, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[10393, 361, 200, 5, 60, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[10596, 368, 99, 2, 43, 42, 0, "StyleData", "Subsection", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10732, 375, 279, 8, 74, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[11014, 385, 296, 8, 56, 43, 0, "StyleData", "Subsubsection", "Lecture",
  CounterIncrements->"Subsubsection"],
Cell[11313, 395, 183, 5, 75, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[11499, 402, 183, 4, 53, 44, 0, "StyleData", "Subsubsection", \
"Printout"],
Cell[11685, 408, 102, 2, 31, 45, 0, "StyleData", "Subsubsection", \
"Condensed"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11836, 416, 39, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[11900, 420, 166, 5, 40, 23, 0, "StyleData", "Text", "All"],
Cell[12069, 427, 178, 5, 40, 34, 0, "StyleData", "Text", "Lecture"],
Cell[12250, 434, 180, 5, 58, 39, 0, "StyleData", "Text", "Presentation"],
Cell[12433, 441, 149, 4, 37, 35, 0, "StyleData", "Text", "Printout"],
Cell[12585, 447, 94, 2, 31, 36, 0, "StyleData", "Text", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12716, 454, 120, 3, 35, 28, 0, "StyleData", "SmallText", "All"],
Cell[12839, 459, 183, 5, 70, 39, 0, "StyleData", "SmallText", "Lecture"],
Cell[13025, 466, 141, 3, 70, 44, 0, "StyleData", "SmallText", \
"Presentation"],
Cell[13169, 471, 113, 2, 70, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[13285, 475, 98, 2, 70, 41, 0, "StyleData", "SmallText", "Condensed"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13432, 483, 35, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[13492, 487, 343, 9, 39, 29, 0, "StyleData", "ListSquare", "All"],
Cell[13838, 498, 236, 7, 58, 45, 0, "StyleData", "ListSquare", \
"Presentation"],
Cell[14077, 507, 162, 4, 37, 41, 0, "StyleData", "ListSquare", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14276, 516, 393, 11, 39, 31, 0, "StyleData", "ListNumbered", "All",
  CounterIncrements->"ListNumbered"],
Cell[14672, 529, 187, 5, 58, 47, 0, "StyleData", "ListNumbered", \
"Presentation"],
Cell[14862, 536, 164, 4, 37, 43, 0, "StyleData", "ListNumbered", "Printout"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15075, 546, 42, 0, 36, "Section"],
Cell[15120, 548, 248, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[15393, 557, 654, 19, 56, 24, 0, "StyleData", "Input", "All"],
Cell[16050, 578, 627, 18, 86, 35, 0, "StyleData", "Input", "Lecture"],
Cell[16680, 598, 172, 5, 94, 40, 0, "StyleData", "Input", "Presentation"],
Cell[16855, 605, 88, 2, 58, 36, 0, "StyleData", "Input", "Printout"],
Cell[16946, 609, 94, 2, 47, 37, 0, "StyleData", "Input", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17077, 616, 663, 20, 56, 28, 0, "StyleData", "InputDemo", "All"],
Cell[17743, 638, 631, 18, 86, 39, 0, "StyleData", "InputDemo", "Lecture"],
Cell[18377, 658, 176, 5, 94, 44, 0, "StyleData", "InputDemo", \
"Presentation"],
Cell[18556, 665, 92, 2, 58, 40, 0, "StyleData", "InputDemo", "Printout"],
Cell[18651, 669, 98, 2, 47, 41, 0, "StyleData", "InputDemo", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18786, 676, 599, 17, 55, 25, 0, "StyleData", "Output", "All"],
Cell[19388, 695, 547, 15, 55, 36, 0, "StyleData", "Output", "Lecture"],
Cell[19938, 712, 227, 6, 67, 41, 0, "StyleData", "Output", "Presentation"],
Cell[20168, 720, 135, 3, 57, 37, 0, "StyleData", "Output", "Printout"],
Cell[20306, 725, 95, 2, 47, 38, 0, "StyleData", "Output", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20438, 732, 447, 12, 38, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[20888, 746, 139, 3, 40, 42, 0, "StyleData", "Message", "Presentation"],
Cell[21030, 751, 139, 3, 35, 38, 0, "StyleData", "Message", "Printout"],
Cell[21172, 756, 96, 2, 31, 39, 0, "StyleData", "Message", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[21305, 763, 446, 12, 38, 24, 0, "StyleData", "Print", "All",
  StyleMenuListing->None],
Cell[21754, 777, 121, 2, 70, 40, 0, "StyleData", "Print", "Presentation"],
Cell[21878, 781, 110, 2, 70, 36, 0, "StyleData", "Print", "Printout"],
Cell[21991, 785, 94, 2, 70, 37, 0, "StyleData", "Print", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[22122, 792, 444, 12, 38, 23, 0, "StyleData", "Info", "All",
  StyleMenuListing->None],
Cell[22569, 806, 120, 2, 70, 39, 0, "StyleData", "Info", "Presentation"],
Cell[22692, 810, 109, 2, 70, 35, 0, "StyleData", "Info", "Printout"],
Cell[22804, 814, 93, 2, 70, 36, 0, "StyleData", "Info", "Condensed"]
}, Closed]],

Cell[CellGroupData[{
Cell[22934, 821, 432, 13, 84, 27, 0, "StyleData", "Graphics", "All",
  StyleMenuListing->None],
Cell[23369, 836, 206, 5, 90, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[23578, 843, 113, 2, 97, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[23694, 847, 97, 2, 31, 40, 0, "StyleData", "Graphics", "Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23828, 854, 128, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[23959, 860, 60, 1, 70, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[24022, 863, 82, 2, 70, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[24107, 867, 56, 1, 70, 41, 0, "StyleData", "CellLabel", "Condensed"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24212, 874, 49, 0, 56, "Section"],
Cell[24264, 876, 227, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[24516, 885, 432, 11, 39, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[24951, 898, 395, 10, 55, 46, 0, "StyleData", "NumberedEquation", \
"Lecture",
  CounterIncrements->"NumberedEquation"],
Cell[25349, 910, 436, 11, 78, 51, 0, "StyleData", "NumberedEquation", \
"Presentation",
  CounterIncrements->"NumberedEquation"],
Cell[25788, 923, 121, 2, 40, 47, 0, "StyleData", "NumberedEquation", \
"Printout"],
Cell[25912, 927, 115, 2, 35, 48, 0, "StyleData", "NumberedEquation", \
"Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26064, 934, 515, 14, 60, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[26582, 950, 153, 4, 107, 49, 0, "StyleData", "NumberedFigure", \
"Presentation"],
Cell[26738, 956, 154, 3, 57, 45, 0, "StyleData", "NumberedFigure", \
"Printout"],
Cell[26895, 961, 103, 2, 31, 46, 0, "StyleData", "NumberedFigure", \
"Condensed"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27035, 968, 309, 7, 60, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[27347, 977, 122, 2, 70, 48, 0, "StyleData", "NumberedTable", \
"Presentation"],
Cell[27472, 981, 118, 2, 70, 44, 0, "StyleData", "NumberedTable", \
"Printout"],
Cell[27593, 985, 102, 2, 70, 45, 0, "StyleData", "NumberedTable", \
"Condensed"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27744, 993, 49, 0, 36, "Section"],
Cell[27796, 995, 94, 3, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[27893, 1000, 94, 3, 70, 29, 0, "StyleData", "LeftHeader", "All",
  StyleMenuListing->None],
Cell[27990, 1005, 119, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[28112, 1011, 94, 3, 70, 29, 0, "StyleData", "LeftFooter", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[28243, 1019, 33, 0, 36, "Section"],
Cell[28279, 1021, 121, 3, 70, "Text"],
Cell[28403, 1026, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28632, 1033, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28930, 1042, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29333, 1053, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29723, 1064, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[30161, 1078, 35, 0, 36, "Section"],
Cell[30199, 1080, 184, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[30408, 1088, 304, 8, 38, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30715, 1098, 361, 10, 38, 39, 0, "StyleData", "Hyperlink", "Lecture",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31079, 1110, 337, 9, 44, 44, 0, "StyleData", "Hyperlink", "Presentation",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31419, 1121, 309, 8, 38, 40, 0, "StyleData", "Hyperlink", "Printout",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Open  ]],
Cell[31743, 1132, 121, 3, 32, "Text"],
Cell[31867, 1137, 277, 7, 38, 27, 0, "StyleData", "RefGuide", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[32181, 1149, 37, 0, 36, "Section"],
Cell[32221, 1151, 115, 3, 70, "Text"],
Cell[32339, 1156, 145, 5, 70, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[32487, 1163, 179, 6, 70, 39, 0, "StyleData", "SelectionPlaceholder", \
"All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[32703, 1174, 36, 0, 36, "Section"],
Cell[32742, 1176, 258, 5, 70, "Text"],
Cell[33003, 1183, 263, 8, 70, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[33269, 1193, 106, 3, 70, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[33378, 1198, 150, 5, 70, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[33531, 1205, 108, 3, 70, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[33642, 1210, 179, 5, 70, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[33824, 1217, 115, 3, 70, "Text"],
Cell[33942, 1222, 163, 5, 70, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

